Package: SigsPack
Type: Package
Title: Mutational Signature Estimation for Single Samples
Version: 1.25.0
Author: Franziska Schumann <franziska.schumann@student.hpi.de>
Maintainer: Franziska Schumann <franziska.schumann@student.hpi.de>
Description: Single sample estimation of exposure to mutational signatures.
    Exposures to known mutational signatures are estimated for single samples,
    based on quadratic programming algorithms. Bootstrapping the input
    mutational catalogues provides estimations on the stability of these 
    exposures. The effect of the sequence composition of mutational context
    can be taken into account by normalising the catalogues.
License: GPL-3
Encoding: UTF-8
Depends: R (>= 3.6)
biocViews: SomaticMutation, SNP, VariantAnnotation,
        BiomedicalInformatics, DNASeq
Imports: quadprog (>= 1.5-5), methods, Biobase, BSgenome (>= 1.46.0),
        VariantAnnotation (>= 1.24.5), Biostrings, GenomeInfoDb,
        GenomicRanges, rtracklayer, SummarizedExperiment, graphics,
        stats, utils
Suggests: IRanges, BSgenome.Hsapiens.UCSC.hg19, BiocStyle, knitr,
        rmarkdown
VignetteBuilder: knitr
BiocViews:
BugReports: https://github.com/bihealth/SigsPack/issues
URL: https://github.com/bihealth/SigsPack
Collate: bootstrap_mut_catalogues.R cosmicSigs.R sigProfilerExome.R
        sigProfiler20190522.R create_mut_catalogues.R decomposeQP.R
        get_context_freq.R hg19context_freq.R normalize.R
        plot_bootstrapped_exposure.R signature_exposure.R
        summarize_exposures.R vcf2mut_cat.R
RoxygenNote: 6.1.1
LazyData: true
git_url: https://git.bioconductor.org/packages/SigsPack
git_branch: devel
git_last_commit: 76511e2
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-05 01:00:13 UTC; biocbuild
