# SigsPack
SigsPack is a R package for mutational signatures estimation. 

Mutational signatures are specific patterns of somatic mutations introduced into the genome by oncogenic processes. 
Different mutational processes often generate different combinations of mutations, or signatures, 
that have been previously described. Identification of the processes contributing to mutations observed in a sample 
is potentially informative to understand the cancer etiology. 

SigsPack provides estimations of a sample's exposure to mutational processes described by a set of known mutational 
signatures (for example from COSMIC). The exposure stability is quantified by bootstrapping the mutational catalogue.
