#' COSMIC Signature Profiles
#'
#' @format A matrix with 30 rows and 96 columns containing the signature 
#' profiles of the 30 consensus signatures as reported on COSMIC.
#' 
#'\describe{
#'\item{Signature N}{The profile of signature N representing the relative
#'proportions of mutations generated by each signature based on the 
#'trinucleotide frequencies of hte reference human genome version GRCh37.}#'}
#'
#' @source \url{https://cancer.sanger.ac.uk/cancergenome/assets/signatures_probabilities.txt}
"cosmicSigs"
