#' Trinuecleotide frequencies of the human reference genome hg19
#'
#' @format A numeric vector with 32 elements
#' 
#'\describe{
#'\item{Trinucleotide}{The frequency of a certain trinucleotide context in the 
#'genome.}}
#'
#' @source BSgenome.Hsapiens.UCSC.hg19
#'
"hg19context_freq"