% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sigProfilerExome.R
\docType{data}
\name{sigProfilerExome}
\alias{sigProfilerExome}
\title{COSMIC v3 exome SBS Signature Profiles}
\format{A matrix with 96 rows and 67 columns containing the signature 
profiles of the 67 consensus signatures as reported on COSMIC version 3.

\describe{
\item{SBS<N>}{The profile of signature SBS<N> representing the relative
proportions of mutations generated by each signature based on the 
trinucleotide frequencies of the reference human genome version GRCh37.
The signature profiles have been normalised for mutational catalogues
collected on exome datasets.}
}}
\source{
\url{https://cancer.sanger.ac.uk/cosmic/signatures/SBS/}
}
\usage{
sigProfilerExome
}
\description{
COSMIC v3 exome SBS Signature Profiles
}
\keyword{datasets}
